@@ -2,9 +2,14 @@ from django.conf import settings
 
 from app_utils.django import clean_setting
 
+from .constants import OperationMode
+
 # switch to enable/disable ability to request standings for corporations
 SR_CORPORATIONS_ENABLED = clean_setting("SR_CORPORATIONS_ENABLED", True)
 
+# Number of seconds to cache heavy pages like character and groups standing
+SR_PAGE_CACHE_SECONDS = clean_setting("SR_PAGE_CACHE_SECONDS", 600)
+
 # whether ESI requests have a timeout
 SR_ESI_TIMEOUT_ENABLED = clean_setting("SR_ESI_TIMEOUT_ENABLED", True)
 
@@ -17,7 +22,7 @@ SR_SYNC_BLUE_ALTS_ENABLED = clean_setting("SR_SYNC_BLUE_ALTS_ENABLED", True)
 
 # Select the entity type of your standings master
 SR_OPERATION_MODE = clean_setting(
-    "SR_OPERATION_MODE", "alliance", choices=["alliance", "corporation"]
+    "SR_OPERATION_MODE", str(OperationMode.ALLIANCE), choices=OperationMode.values
 )
 
 # This is a map, where the key is the State the user is in
@@ -41,7 +46,7 @@ SR_STANDING_TIMEOUT_HOURS = clean_setting("SR_STANDING_TIMEOUT_HOURS", 24)
 STANDINGS_API_CHARID = clean_setting("STANDINGS_API_CHARID", None, required_type=int)
 
 # charaters belonging to these alliances are considered to be "in organization"
-STR_ALLIANCE_IDS = clean_setting("STR_ALLIANCE_IDS", None, required_type=list)
+STR_ALLIANCE_IDS = clean_setting("STR_ALLIANCE_IDS", [], required_type=list)
 
 # charaters belonging to these corporations are considered to be "in organization"
-STR_CORP_IDS = clean_setting("STR_CORP_IDS", None, required_type=list)
+STR_CORP_IDS = clean_setting("STR_CORP_IDS", [], required_type=list)
