@@ -2,6 +2,9 @@ from enum import IntEnum
 
 from django.db.models import TextChoices
 
+DATETIME_FORMAT_HTML = "Y-m-d H:i"
+DATETIME_FORMAT_PY = "%Y-%m-%d %H:%M"
+
 
 class OperationMode(TextChoices):
     ALLIANCE = "alliance"
